@@ -75,10 +75,6 @@ KConfigSkeleton* RBackend::config() const
 
 QUrl RBackend::helpUrl() const
 {
-    const QUrl& localDoc = RServerSettings::self()->localDoc();
-    if (!localDoc.isEmpty())
-        return localDoc;
-    else
     return QUrl(i18nc("the url to the documentation of R, please check if there is a translated version and use the correct url",
                  "https://cran.r-project.org/manuals.html"));
 }
