@@ -28,7 +28,15 @@ m_isHelpRequest(false)
 
 void RExpression::evaluate()
 {
-    if(command().startsWith(QLatin1Char('?')))
+    const auto& cmd = command();
+
+    //check whether we need to interpret the current command as a help command.
+    //see https://www.r-project.org/help.html for the list of different ways to get help in R.
+    if(cmd.startsWith(QLatin1Char('?')) || cmd.startsWith(QStringLiteral("help("))
+        || cmd.startsWith(QStringLiteral("apropos("))
+        || cmd.startsWith(QStringLiteral("vignette("))
+        || cmd == QStringLiteral("demos()")
+        || cmd.startsWith(QStringLiteral("help.search(")) )
         m_isHelpRequest=true;
     else
         m_isHelpRequest=false;
@@ -46,7 +54,12 @@ void RExpression::parseOutput(const QString& text)
 {
     //qDebug() << "output text: " << text;
     if (!text.trimmed().isEmpty())
-        addResult(new Cantor::TextResult(text));
+    {
+        if(m_isHelpRequest)
+            addResult(new Cantor::HelpResult(text));
+        else
+            addResult(new Cantor::TextResult(text));
+    }
     setStatus(Cantor::Expression::Done);
 }
 
@@ -78,11 +91,13 @@ void RExpression::showFilesAsResult(const QStringList& files)
             setResult(new Cantor::EpsResult(QUrl::fromLocalFile(file)));
         }
         else if(type.inherits(QLatin1String("text/plain"))
-            || type.inherits(QLatin1String("application/x-extension-html")))
+            || type.inherits(QLatin1String("application/x-extension-html"))
+            ||type.inherits(QLatin1String("application/octet-stream")) )
         {
             //Htmls are also plain texts, combining this in one
             const bool isHtml = type.inherits(QLatin1String("text/html"))
-                || type.inherits(QLatin1String("application/x-extension-html"));
+                || type.inherits(QLatin1String("application/x-extension-html"))
+                || type.inherits(QLatin1String("application/octet-stream"));
             if(isHtml)
                 qDebug()<<"it's a HTML document";
             else
