@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+*/
 
 #ifndef _TESTOCTAVE_H
 #define _TESTOCTAVE_H
@@ -43,10 +28,11 @@ private Q_SLOTS:
     void testVariableDefinition();
     void testMatrixDefinition();
 
-    //some tests to see if comments are working correctly
-    void testSimpleExpressionWithComment();
-    void testCommentExpression();
-    void testMultilineCommandWithComment();
+    //comments
+    void testComment00();
+    void testComment01();
+    void testComment02();
+    void testComment03();
 
     //tests a syntax error (not closing bracket)
     void testInvalidSyntax();
