@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2015 Minh Ngo <minh@fedoraproject.org>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2015 Minh Ngo <minh@fedoraproject.org>
+*/
 
 #include "testpython.h"
 
@@ -118,9 +103,7 @@ void TestPython3::testCompletion()
     waitForSignal(help, SIGNAL(fetchingDone()));
 
     // Checks all completions for this request
-    // This correct for Python 3.6.7
     const QStringList& completions = help->completions();
-    qDebug() << completions;
     QCOMPARE(completions.size(), 4);
     QVERIFY(completions.contains(QLatin1String("pass")));
     QVERIFY(completions.contains(QLatin1String("pow")));
@@ -325,7 +308,6 @@ void TestPython3::testInterrupt()
     QCOMPARE(e2->status(), Cantor::Expression::Interrupted);
 
     Cantor::Expression* e = evalExp(QLatin1String("2+2"));
-    qDebug() << e->status() << session()->status();
 
     QVERIFY(e != nullptr);
     QCOMPARE(e->status(), Cantor::Expression::Done);
@@ -338,6 +320,10 @@ void TestPython3::testWarning()
     Cantor::Expression* e = evalExp(QLatin1String("import warnings; warnings.warn('Test')"));
 
     QVERIFY(e != nullptr);
+
+    while(session()->status() != Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
+
     QCOMPARE(e->status(), Cantor::Expression::Status::Done);
     QCOMPARE(e->results().size(), 1);
 }
