@@ -1,21 +1,9 @@
-/*************************************************************************************
-*  Copyright (C) 2009 by Milian Wolff <mail@milianw.de>                             *
-*  Copyright (C) 2011 by Matteo Agostinelli <agostinelli@gmail.com>                 *
-*                                                                                   *
-*  This program is free software; you can redistribute it and/or                    *
-*  modify it under the terms of the GNU General Public License                      *
-*  as published by the Free Software Foundation; either version 2                   *
-*  of the License, or (at your option) any later version.                           *
-*                                                                                   *
-*  This program is distributed in the hope that it will be useful,                  *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
-*  GNU General Public License for more details.                                     *
-*                                                                                   *
-*  You should have received a copy of the GNU General Public License                *
-*  along with this program; if not, write to the Free Software                      *
-*  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
-*************************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Milian Wolff <mail@milianw.de>
+    SPDX-FileCopyrightText: 2011 Matteo Agostinelli <agostinelli@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <config-cantorlib.h>
 
@@ -60,7 +48,7 @@ QalculateExpression::QalculateExpression( QalculateSession* session, bool intern
 QalculateExpression::~QalculateExpression()
 {
     if (m_tempFile)
-	delete m_tempFile;
+        delete m_tempFile;
 }
 
 void QalculateExpression::evaluate()
@@ -117,10 +105,9 @@ void QalculateExpression::updateVariables()
 {
     QalculateSession* currentSession = dynamic_cast<QalculateSession*>(session());
     QMap<QString,QString>  &variables = currentSession->variables;
-    Cantor::DefaultVariableModel* model = static_cast<Cantor::DefaultVariableModel*>(currentSession->variableModel());
     QMap<QString, QString>::const_iterator it = variables.constBegin();
     while (it != variables.constEnd()) {
-        model->addVariable(it.key(), it.value());
+        currentSession->variableModel()->addVariable(it.key(), it.value());
         ++it;
     }
 }
