@@ -1,28 +1,13 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2011 Filipe Saraiva <filipe@kde.org>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2011 Filipe Saraiva <filipe@kde.org>
+*/
 
 #include "scilabbackend.h"
 #include "scilabsession.h"
 #include "scilabextensions.h"
+#include "scilabsettingswidget.h"
 #include "settings.h"
-#include "ui_settings.h"
 
 
 ScilabBackend::ScilabBackend(QObject* parent,const QList<QVariant> args) : Cantor::Backend(parent, args)
@@ -68,10 +53,7 @@ bool ScilabBackend::requirementsFullfilled(QString* const reason) const
 
 QWidget* ScilabBackend::settingsWidget(QWidget* parent) const
 {
-    QWidget* widget=new QWidget(parent);
-    Ui::ScilabSettingsBase s;
-    s.setupUi(widget);
-    return widget;
+    return new ScilabSettingsWidget(parent, id());
 }
 
 KConfigSkeleton* ScilabBackend::config() const
