@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+*/
 
 #include "cantor.h"
 #include <config-cantor.h>
@@ -32,12 +17,19 @@
 #include <QFileInfo>
 #include <QDir>
 #include <QDebug>
+#include <QtWebEngine>
 
 static const char description[] =
     I18N_NOOP("KDE Frontend to mathematical applications");
 
 int main(int argc, char **argv)
 {
+    QtWebEngine::initialize();
+    // Register custom scheme handler for qthelp:// scheme
+    QWebEngineUrlScheme qthelp("qthelp");
+    QWebEngineUrlScheme::registerScheme(qthelp);
+
+    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
 
     // Add our custom plugins path, where we install our plugins, if it isn't default path
