@@ -1,35 +1,18 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2012 Martin Kuettler <martin.kuettler@gmail.com>
+    SPDX-FileCopyrightText: 2018-2021 Alexander Semke <alexander.semke@web.de>
+*/
 
 #include "worksheetview.h"
 #include "worksheet.h"
 
+#include <QFocusEvent>
 #include <QParallelAnimationGroup>
 #include <QPropertyAnimation>
 #include <QScrollBar>
 
 WorksheetView::WorksheetView(Worksheet* scene, QWidget* parent) : QGraphicsView(scene, parent),
-    m_scale(1),
-    m_animation(nullptr),
-    m_hAnimation(nullptr),
-    m_vAnimation(nullptr),
     m_worksheet(scene)
 {
     connect(scene, SIGNAL(sceneRectChanged(QRectF)),
@@ -245,6 +228,20 @@ void WorksheetView::resizeEvent(QResizeEvent* event)
     updateSceneSize();
 }
 
+void WorksheetView::focusInEvent(QFocusEvent* event)
+{
+    QGraphicsView::focusInEvent(event);
+    m_worksheet->resumeAnimations();
+}
+
+void WorksheetView::focusOutEvent(QFocusEvent* event)
+{
+    QGraphicsView::focusOutEvent(event);
+    if (!scene()->hasFocus())
+        m_worksheet->stopAnimations();
+}
+
+
 qreal WorksheetView::scaleFactor() const
 {
     return m_scale;
